@@ -44,7 +44,7 @@ class FakeMikrotikClient():
 
     async def login(self, *args, **kwargs):
         self.attempted_logins[(self._user, self._pass)] = self.attempted_logins.get((self._user, self._pass), 0) + 1
-        raise MikrotikApiError('invalid credentials')
+        raise MikrotikApiError('invalid user name or password')
 
 
 @staticmethod
@@ -952,6 +952,12 @@ class TestNetworkElement(unittest.TestCase):
         # An AP uses matching credentials.
         ne = self._setup_mikrotik_ne('ap', cfg)
         self._await(ne.poll())
+        self.assertEqual(set(FakeMikrotikClient.attempted_logins), ap_creds)
+
+        # A router uses matching credentials.
+        ne = self._setup_mikrotik_ne('router', cfg)
+        self._await(ne.poll())
+        self.assertEqual(set(FakeMikrotikClient.attempted_logins), router_creds)
 
     def test_send_update_1(self):
         """Verify that send_update sends network_element_update_msg when matching elem_discovery
